Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(233)

Unified Diff: chromeos/printing/ppd_provider.h

Issue 2814633002: Add CupsFilter extraction from resolved ppds for printing. (Closed)
Patch Set: Address skau@ comments Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chromeos/printing/ppd_provider.h
diff --git a/chromeos/printing/ppd_provider.h b/chromeos/printing/ppd_provider.h
index 0b378357c48a44b5d3bb161bd04031163bc0b7c8..26ae49fdc2f794264e473753fae97654526a8174 100644
--- a/chromeos/printing/ppd_provider.h
+++ b/chromeos/printing/ppd_provider.h
@@ -57,11 +57,15 @@ class CHROMEOS_EXPORT PpdProvider : public base::RefCounted<PpdProvider> {
std::string ppd_server_root = "https://www.gstatic.com/chromeos_printing";
};
// Result of a ResolvePpd() call. If the result code is SUCCESS, then the
// string holds the contents of a PPD (that may or may not be gzipped).
// Otherwise, the string will be empty.
using ResolvePpdCallback =
- base::Callback<void(CallbackResultCode, const std::string&)>;
+ base::Callback<void(CallbackResultCode,
+ const std::string&,
+ const std::vector<std::string>& required_filters)>;
// Result of a ResolveManufacturers() call. If the result code is SUCCESS,
// then the vector contains a sorted list of manufacturers for which we have
« no previous file with comments | « chrome/browser/ui/webui/settings/chromeos/cups_printers_handler.h ('k') | chromeos/printing/ppd_provider.cc » ('j') | no next file with comments »
@@ -57,11 +57,15 @@ class CHROMEOS_EXPORT PpdProvider : public base::RefCounted<PpdProvider> {
std::string ppd_server_root = "https://www.gstatic.com/chromeos_printing";
};
- // Result of a ResolvePpd() call. If the result code is SUCCESS, then the
- // string holds the contents of a PPD (that may or may not be gzipped).
- // Otherwise, the string will be empty.
+ // Result of a ResolvePpd() call.
+ // If the result code is SUCCESS, then:
+ // string holds the contents of a PPD (that may or may not be gzipped).
+ // required_filters holds the names of the filters referenced in the ppd.
+ // Otherwise, these fields will be empty.
using ResolvePpdCallback =

Powered by Google App Engine
This is Rietveld 408576698